Package: shiny.webawesome
Title: 'shiny' Bindings for 'Web Awesome' Components
Version: 1.0.0
Authors@R: 
    person("M. B.", "Anand", , "privateanand@gmail.com", role = c("aut", "cre"))
Description: Provides an 'R' and 'shiny' interface to the 'Web Awesome'
    component library. The package is generator-driven, exposing 'Web Awesome'
    web components as 'R' functions that produce HTML tags and integrate with
    the reactive model that 'shiny' uses.
URL: https://github.com/mbanand/shiny.webawesome,
        https://www.shiny-webawesome.org
BugReports: https://github.com/mbanand/shiny.webawesome/issues
License: MIT + file LICENSE
Encoding: UTF-8
Imports: htmltools, shiny
RoxygenNote: 7.3.3
Suggests: chromote, covr, devtools, digest, document, jsonlite, knitr,
        lintr, processx, pkgdown, rmarkdown, rhub, shinytest2, styler,
        testthat (>= 3.0.0), urlchecker, withr, yaml
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-17 15:45:14 UTC; vmuser
Author: M. B. Anand [aut, cre]
Maintainer: M. B. Anand <privateanand@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-21 19:32:09 UTC
Built: R 4.6.0; ; 2026-04-26 15:08:09 UTC; unix
